% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/trimPeaks.R
\name{trimPeaks}
\alias{trimPeaks}
\title{Trim peaks}
\usage{
trimPeaks(se, cutoffPvalue = 0.05, backgroundPercentage = 0.25,
  countFilter = 1000, ratioAssay = "ratio",
  backgroundCorrectionAssay = "bcRatio",
  smoothedRatioAssay = "smoothedRatio", zscoreAssay = "zscore")
}
\arguments{
\item{se}{An object of 
\link[SummarizedExperiment]{RangedSummarizedExperiment}
with assays of raw counts, ratios, background correct ratios,
smoothed ratios and z-scores. It should be an element of output of 
\link{smoothRatiosByChromosome}}

\item{cutoffPvalue}{numeric(1). Cutoff p-value.}

\item{backgroundPercentage}{numeric(1). Cutoff value for the peaks height.}

\item{countFilter}{numeric(1) or integer(1). Cutoff value for mean of 
raw reads count in each window.}

\item{ratioAssay}{character(1). The name of assay in se, which store the 
values to be smoothed.}

\item{backgroundCorrectionAssay, smoothedRatioAssay, zscoreAssay}{Assays names 
for background correction ratios, smoothed ratios and z-score based on
background correction ratios.}
}
\value{
An object of \link[GenomicRanges]{GRanges}.
}
\description{
Filter the peaks by pvalue and trim the range of peaks 
for sample without duplicates.
}
\examples{

data(single.count)
se <- single.count
## Calculate ratios for peak calling. We use signal vs input.
dat <- log2se(se, nucleosomeCols="nucleosome.bam", genomeCols="genome.bam")
## Smooth the ratios for each chromosome.
dat <- smoothRatiosByChromosome(dat, N=100)
peaks <- trimPeaks(dat[["chr18"]],
                backgroundPercentage=.25,
                cutoffPvalue=0.05, countFilter=1000)

}
